/* 
 * Paolo De Pasquale 28/03/2022
 * 
 * Load Cell HX711 Module Interface with Arduino to measure weight in Kgs
 Arduino 
 pin 
 2 -> HX711 CLK
 3 -> DOUT
 5V -> VCC
 
 GND -> GND
 
 The HX711 board can be powered from 2.7V to 5V so the Arduino 5V power should be fine.
*/
 
#include "HX711.h"  //You must have this library in your arduino library folder
#include "SoftwareSerial.h"
// 
#define DOUT  3
#define CLK  2
 
HX711 scale;
//PrintWriter output;

//Change this calibration factor as per your load cell once it is found you many need to vary it in thousands
float calibration_factor = 11463;
float offset = 0;
unsigned long time0 = 0; 
const int arduinoPowerGreenLedPin = 7;
const int arduinoPowerVoltagePin  = A0;
float arduinoPowerVoltage = 0.0;

//=============================================================================================
//                         SETUP
//=============================================================================================
void setup() {


  Serial.begin(9600);
  //output = createWriter( "data.txt" );
  scale.begin(DOUT,CLK);
  //scale.begin(A1, A0);
//  Serial.println("HX711 Calibration");
//  Serial.println("Remove all weight from scale");
//  Serial.println("After readings begin, place known weight on scale");
//  Serial.println("Press a,s,d,f to increase calibration factor by 10,100,1000,10000 respectively");
//  Serial.println("Press z,x,c,v to decrease calibration factor by 10,100,1000,10000 respectively");
//  Serial.println("Press t for tare");
  scale.set_gain(64);
  scale.set_scale();
  scale.set_offset(offset);
  scale.tare(); //Reset the scale to 0
 
  long zero_factor = scale.read_average(); //Get a baseline reading
//  Serial.print("Zero factor: "); //This can be used to remove the need to tare the scale. Useful in permanent scale projects.
//  Serial.println(zero_factor);

  time0 = millis();
  pinMode(arduinoPowerGreenLedPin, OUTPUT);
  
}
 
//=============================================================================================
//                         LOOP
//=============================================================================================
void loop() {


  scale.set_scale(calibration_factor); //Adjust to this calibration factor
  digitalWrite(arduinoPowerGreenLedPin, HIGH);

  //Serial.print("Reading: ");
  Serial.print(millis()-time0);
  Serial.print(",");
  //Serial.print(scale.get_units(2),3);
  Serial.print(scale.get_units(1),4);
  Serial.print(",");
  Serial.print(arduinoPowerMonitor());
  //Serial.print(",");
  //Serial.print(calibration_factor);
  //Serial.print(" kg"); //Change this to kg and re-adjust the calibration factor if you follow SI units like a sane person
  //Serial.print(" calibration_factor: ");
  //Serial.print(calibration_factor);
  Serial.println();
  //Serial.print(" writing file... ");
  //output.println( scale.get_units(10) );
  
  if(Serial.available())
  {
    char temp = Serial.read();
    if(temp == '+' || temp == 'a')
      calibration_factor += 100;
    else if(temp == '-' || temp == 'z')
      calibration_factor -= 100;
    else if(temp == 's')
      calibration_factor += 1000;  
    else if(temp == 'x')
      calibration_factor -= 1000;  
    else if(temp == 'd')
      calibration_factor += 10000;  
    else if(temp == 'c')
      calibration_factor -= 10000;
    else if(temp == 'f')
      calibration_factor += 100000;  
    else if(temp == 'v')
      calibration_factor -= 100000;  
    else if(temp == 't')
      scale.tare();  //Reset the scale to zero
  }
  //digitalWrite(13, LOW);
}
  

void keyPressed() {
    //output.flush();  // Writes the remaining data to the file
    //output.close();  // Finishes the file
    //exit();  // Stops the program
}

float arduinoPowerMonitor() {
  
  float analogRaw = analogRead(arduinoPowerVoltagePin);
  arduinoPowerVoltage = analogRaw / 1024.0 * 5.0;
  return analogRaw;
  
  /*Serial.print("analogRaw: ");
  Serial.print(analogRaw);
  Serial.print(",");
  Serial.print("fractionalVoltage: ");
  Serial.print(fractionalVoltage);
  Serial.print(",");
  Serial.print(" arduinoPowerVoltage: ");
  Serial.println(arduinoPowerVoltage);
  delay(1000);
*/
}

//=============================================================================================
